@@ -5,7 +5,7 @@ use warnings;
 package Dist::Iller;
 
 # ABSTRACT: A Dist::Zilla & Pod::Weaver preprocessor
-our $VERSION = '0.1403';
+our $VERSION = '0.1404';
 
 use Dist::Iller::Elk;
 use Types::Standard qw/Map Str ConsumerOf/;
@@ -77,6 +77,7 @@ sub parse {
             }
 
             next DOC if $doc->[0] eq 'dist';
+            next DOC if $doc->[0] eq 'cpanfile';
             if($doc->[1]->$_does('Dist::Iller::Role::HasPrereqs')) {
                 $self->get_doc('dist')->merge_prereqs($doc->[1]->all_prereqs);
             }
@@ -89,8 +90,12 @@ sub parse {
 
 sub generate_files {
     my $self = shift;
+    my $phase = shift;
+
+    croak q{'phase' must be either 'before' or 'after'} if !defined $phase || $phase ne 'before' && $phase ne 'after';
 
     for my $doc ($self->doc_kv) {
+        next if $doc->[1]->phase ne $phase;
         $doc->[1]->generate_file;
     }
 }
@@ -113,20 +118,20 @@ Dist::Iller - A Dist::Zilla & Pod::Weaver preprocessor
 
 =begin HTML
 
-<p><img src="https://img.shields.io/badge/perl-5.10.1+-brightgreen.svg" alt="Requires Perl 5.10.1+" /> <a href="https://travis-ci.org/Csson/p5-Dist-Iller"><img src="https://api.travis-ci.org/Csson/p5-Dist-Iller.svg?branch=master" alt="Travis status" /></a> <img src="https://img.shields.io/badge/coverage-82.0%-orange.svg" alt="coverage 82.0%" /></p>
+<p><img src="https://img.shields.io/badge/perl-5.10.1+-brightgreen.svg" alt="Requires Perl 5.10.1+" /> <a href="https://travis-ci.org/Csson/p5-Dist-Iller"><img src="https://api.travis-ci.org/Csson/p5-Dist-Iller.svg?branch=master" alt="Travis status" /></a> <img src="https://img.shields.io/badge/coverage-83.8%-orange.svg" alt="coverage 83.8%" /></p>
 
 =end HTML
 
 
 =begin markdown
 
-![Requires Perl 5.10.1+](https://img.shields.io/badge/perl-5.10.1+-brightgreen.svg) [![Travis status](https://api.travis-ci.org/Csson/p5-Dist-Iller.svg?branch=master)](https://travis-ci.org/Csson/p5-Dist-Iller) ![coverage 82.0%](https://img.shields.io/badge/coverage-82.0%-orange.svg)
+![Requires Perl 5.10.1+](https://img.shields.io/badge/perl-5.10.1+-brightgreen.svg) [![Travis status](https://api.travis-ci.org/Csson/p5-Dist-Iller.svg?branch=master)](https://travis-ci.org/Csson/p5-Dist-Iller) ![coverage 83.8%](https://img.shields.io/badge/coverage-83.8%-orange.svg)
 
 =end markdown
 
 =head1 VERSION
 
-Version 0.1403, released 2016-02-10.
+Version 0.1404, released 2016-02-11.
 
 =head1 SYNOPSIS
 
