@@ -4,7 +4,7 @@ use warnings;
 
 package Dist::Iller::DocType::Dist;
 
-our $VERSION = '0.1403';
+our $VERSION = '0.1404';
 
 use Dist::Iller::Elk;
 with qw/
@@ -57,6 +57,8 @@ has copyright_year => (
 
 sub filename { 'dist.ini' }
 
+sub phase { 'before' }
+
 sub comment_start { ';' }
 
 sub parse {
@@ -65,7 +67,6 @@ sub parse {
     $self->parse_header($yaml->{'header'});
     $self->parse_prereqs($yaml->{'prereqs'});
     $self->parse_plugins($yaml->{'plugins'});
-    return $self;
 }
 
 around qw/parse_header parse_prereqs/ => sub {
@@ -247,7 +248,7 @@ Dist::Iller::DocType::Dist
 
 =head1 VERSION
 
-Version 0.1403, released 2016-02-10.
+Version 0.1404, released 2016-02-11.
 
 =head1 SOURCE
 
