@@ -4,7 +4,7 @@ use warnings;
 
 package Dist::Iller::DocType::Weaver;
 
-our $VERSION = '0.1403';
+our $VERSION = '0.1404';
 
 use Dist::Iller::Elk;
 with qw/
@@ -14,14 +14,14 @@ with qw/
 
 sub filename { 'weaver.ini' }
 
+sub phase { 'before' }
+
 sub comment_start { ';' }
 
 sub parse {
     my $self = shift;
     my $yaml = shift;
     $self->parse_plugins($yaml->{'plugins'});
-
-    return $self;
 }
 
 sub to_hash {
@@ -91,7 +91,7 @@ Dist::Iller::DocType::Weaver
 
 =head1 VERSION
 
-Version 0.1403, released 2016-02-10.
+Version 0.1404, released 2016-02-11.
 
 =head1 SOURCE
 
